==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/QCustom3DLabel_shell.h <==
#ifndef QCUSTOM3DLABEL_SHELL_H
#define QCUSTOM3DLABEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qcustom3dlabel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qimage.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


class QCustom3DLabel_shell : public QtDataVisualization::QCustom3DLabel, public QtJambiShellInterface
{
public:
    QCustom3DLabel_shell(QObject* parent0 = nullptr);
    QCustom3DLabel_shell(const QString& text0, const QFont& font1, const QVector3D& position2, const QVector3D& scaling3, const QQuaternion& rotation4, QObject* parent5 = nullptr);
    ~QCustom3DLabel_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCustom3DLabel_access : public QtDataVisualization::QCustom3DLabel
{
};

#endif // QCUSTOM3DLABEL_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiDataVisualization/QCustom3DLabel_shell.h <==
#ifndef QCUSTOM3DLABEL_SHELL_H
#define QCUSTOM3DLABEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qcustom3dlabel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qimage.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


class QCustom3DLabel_shell : public QCustom3DLabel, public QtJambiShellInterface
{
public:
    QCustom3DLabel_shell(QObject* parent0 = nullptr);
    QCustom3DLabel_shell(const QString& text0, const QFont& font1, const QVector3D& position2, const QVector3D& scaling3, const QQuaternion& rotation4, QObject* parent5 = nullptr);
    ~QCustom3DLabel_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCustom3DLabel_access : public QCustom3DLabel
{
};

#endif // QCUSTOM3DLABEL_SHELL_H
